aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/gdisp/ILI9320/board_ILI9320_olimex_pic32mx_lcd.h
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/gdisp/ILI9320/board_ILI9320_olimex_pic32mx_lcd.h')
-rw-r--r--drivers/gdisp/ILI9320/board_ILI9320_olimex_pic32mx_lcd.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/gdisp/ILI9320/board_ILI9320_olimex_pic32mx_lcd.h b/drivers/gdisp/ILI9320/board_ILI9320_olimex_pic32mx_lcd.h
index cf101aaf..5315127b 100644
--- a/drivers/gdisp/ILI9320/board_ILI9320_olimex_pic32mx_lcd.h
+++ b/drivers/gdisp/ILI9320/board_ILI9320_olimex_pic32mx_lcd.h
@@ -19,8 +19,8 @@
static void init_board(GDisplay *g) {
- // As we are not using multiple displays we set g->priv to NULL as we don't use it.
- g->priv = 0;
+ // As we are not using multiple displays we set g->board to NULL as we don't use it.
+ g->board = 0;
switch(g->controllerdisplay) {
case 0: // Set up for Display 0